@@ -36,7 +36,7 @@ class ListSubmissions(GraphQLRequest):
             $limit: Int,
             $orderBy: SUBMISSION_COLUMN_ENUM,
             $desc: Boolean
-            
+
         ){
             submissions(
                 submissionIds: $submissionIds,
@@ -45,7 +45,7 @@ class ListSubmissions(GraphQLRequest):
                 limit: $limit
                 orderBy: $orderBy,
                 desc: $desc
-                
+
             ){
                 submissions {
                     id
@@ -64,14 +64,14 @@ class ListSubmissions(GraphQLRequest):
     """
 
     def __init__(
-            self,
-            *,
-            submission_ids: List[int] = None,
-            workflow_ids: List[int] = None,
-            filters: Union[Dict, SubmissionFilter] = None,
-            limit: int = 1000,
-            order_by: str = "ID",
-            desc: bool = True,
+        self,
+        *,
+        submission_ids: List[int] = None,
+        workflow_ids: List[int] = None,
+        filters: Union[Dict, SubmissionFilter] = None,
+        limit: int = 1000,
+        order_by: str = "ID",
+        desc: bool = True,
     ):
         super().__init__(
             self.query,
@@ -120,14 +120,8 @@ class GetSubmission(GraphQLRequest):
         }
     """
 
-    def __init__(
-            self,
-            submission_id: int,
-    ):
-        super().__init__(
-            self.query,
-            variables={"submissionId": submission_id},
-        )
+    def __init__(self, submission_id: int):
+        super().__init__(self.query, variables={"submissionId": submission_id})
 
     def process_response(self, response) -> Submission:
         return Submission(**(super().process_response(response)["submission"]))
@@ -161,11 +155,7 @@ class WaitForSubmissions(RequestChain):
         }
     """
 
-    def __init__(
-            self,
-            submission_ids: List[int],
-            timeout: Union[int, float] = 60,
-    ):
+    def __init__(self, submission_ids: List[int], timeout: Union[int, float] = 60):
         if not submission_ids:
             raise IndicoInputError("Please provide submission ids")
 
@@ -180,8 +170,8 @@ class WaitForSubmissions(RequestChain):
         yield self.status_getter()
         curr_time = 0
         while (
-                not all(self.status_check(s.status) for s in self.previous)
-                and curr_time <= self.timeout
+            not all(self.status_check(s.status) for s in self.previous)
+            and curr_time <= self.timeout
         ):
             yield self.status_getter()
             time.sleep(1)
@@ -251,10 +241,7 @@ class GenerateSubmissionResult(GraphQLRequest):
 
     def __init__(self, submission: Union[int, Submission]):
         submission_id = submission if isinstance(submission, int) else submission.id
-        super().__init__(
-            self.query,
-            variables={"submissionId": submission_id},
-        )
+        super().__init__(self.query, variables={"submissionId": submission_id})
 
     def process_response(self, response) -> Job:
         response = super().process_response(response)["submissionResults"]
@@ -288,11 +275,11 @@ class SubmissionResult(RequestChain):
     previous: Submission = None
 
     def __init__(
-            self,
-            submission: Union[int, Submission],
-            check_status: str = None,
-            wait: bool = False,
-            timeout: Union[int, float] = 30,
+        self,
+        submission: Union[int, Submission],
+        check_status: str = None,
+        wait: bool = False,
+        timeout: Union[int, float] = 30,
     ):
         self.submission_id = (
             submission if isinstance(submission, int) else submission.id
@@ -315,8 +302,8 @@ class SubmissionResult(RequestChain):
         if self.wait:
             curr_time = 0
             while (
-                    not self.status_check(self.previous.status)
-                    and curr_time <= self.timeout
+                not self.status_check(self.previous.status)
+                and curr_time <= self.timeout
             ):
                 yield GetSubmission(self.submission_id)
                 time.sleep(1)
@@ -369,11 +356,11 @@ class SubmitReview(GraphQLRequest):
     }
 
     def __init__(
-            self,
-            submission: Union[int, Submission],
-            changes: Dict = None,
-            rejected: bool = False,
-            force_complete: bool = None,
+        self,
+        submission: Union[int, Submission],
+        changes: Dict = None,
+        rejected: bool = False,
+        force_complete: bool = None,
     ):
         submission_id = submission if isinstance(submission, int) else submission.id
         if not changes and not rejected:
@@ -412,6 +399,7 @@ class RetrySubmission(GraphQLRequest):
     Attributes:
         submission_ids (List[int]): the given submission ids to retry.
     """
+
     query = """
     mutation retrySubmission($submissionIds:[Int]!){
   retrySubmissions(submissionIds: $submissionIds){
@@ -433,10 +421,7 @@ class RetrySubmission(GraphQLRequest):
         if submission_ids is None or len(submission_ids) < 1:
             raise IndicoInputError("You must specify submission ids")
 
-        super().__init__(
-            self.query,
-            variables={"submissionIds": submission_ids},
-        )
+        super().__init__(self.query, variables={"submissionIds": submission_ids})
 
     def process_response(self, response) -> List[Submission]:
         return [
